@@ -7,7 +7,7 @@ use File::Spec;
 use DBI;
 use Carp;
 
-our $VERSION = '0.99_01';
+our $VERSION = '0.99_02';
 
 use Test::Database::Driver;
 
@@ -53,7 +53,39 @@ sub _rcfile {
 
 sub _canonicalize_drivers {
     my %seen;
-    @DRIVERS = grep { !$seen{ $_->as_string() }++ } @DRIVERS;
+    @DRIVERS = grep { !$seen{ $_->as_string() }++ } grep {defined} @DRIVERS;
+}
+
+sub _read_file {
+    my ($file) = @_;
+    my @config;
+
+    open my $fh, '<', $file or croak "Can't open $file for reading: $!";
+    my %args;
+    while (<$fh>) {
+        next if /^\s*(?:#|$)/;    # skip blank lines and comments
+        chomp;
+
+        /\s*(\w+)\s*=\s*(.*)\s*/ && do {
+            my ( $key, $value ) = ( $1, $2 );
+            $value = Test::Database::Driver::_unquote($value)
+                if $value =~ /\A["']/;
+            if ( $key eq 'driver' && keys %args ) {
+                push @config, {%args};
+                %args = ();
+            }
+            $args{$key} = $value;
+            next;
+        };
+
+        # unknown line
+        croak "Can't parse line at $file, line $.:\n  <$_>";
+    }
+    push @config, {%args}
+        if keys %args;
+    close $fh;
+
+    return @config;
 }
 
 #
@@ -79,31 +111,7 @@ sub load_drivers {
     my ( $class, $file ) = @_;
     $file = _rcfile() if !defined $file;
 
-    my %args;
-    open my $fh, '<', $file or croak "Can't open $file for reading: $!";
-    while (<$fh>) {
-        next if /^\s*(?:#|$)/;    # skip blank lines and comments
-        chomp;
-
-        /\s*(\w+)\s*=\s*(.*)\s*/ && do {
-            my ( $key, $value ) = ( $1, $2 );
-            $value = Test::Database::Driver::_unquote( $value )
-                 if $value =~ /\A["']/;
-            if ( $key eq 'driver' && keys %args ) {
-                push @DRIVERS, Test::Database::Driver->new(%args);
-                %args = ();
-            }
-            $args{$key} = $value;
-            next;
-            };
-
-        # unknown line
-        croak "Can't parse line at $file, line $.:\n  <$_>";
-    }
-    push @DRIVERS, Test::Database::Driver->new(%args)
-        if keys %args;
-    close $fh;
-
+    push @DRIVERS, map { Test::Database::Driver->new(%$_) } _read_file($file);
     _canonicalize_drivers();
 }
 
@@ -147,8 +155,7 @@ sub handles {
 }
 
 sub cleanup {
-    $_->cleanup()
-        for map { Test::Database::Driver->new( driver => $_ ) } @DRIVERS_OK;
+    $_->cleanup() for @DRIVERS;
 }
 
 'TRUE';
